@@ -1,8 +1,8 @@
 # coding: utf-8
 
 from django import forms
-from django.utils.encoding import force_text
-from django.utils.translation import ugettext_lazy as _
+from django.utils.encoding import force_str
+from django.utils.translation import gettext_lazy as _
 
 M = _('Hold down "Control", or "Command" on a Mac, to select more than one.')
 
@@ -19,7 +19,7 @@ class FixedModelForm(forms.ModelForm):
     def __init__(self, *args, **kwargs):
         super(FixedModelForm, self).__init__(*args, **kwargs)
 
-        msg = force_text(M)
+        msg = force_str(M)
 
         for name, field in self.fields.items():
             field.help_text = field.help_text.replace(msg, '')
