@@ -1,6 +1,5 @@
 import json
 
-import django
 from django import forms
 from django.conf import settings
 from django.utils.safestring import mark_safe
@@ -39,15 +38,25 @@ class Select2Mixin(object):
         super(Select2Mixin, self).__init__(*args, **kwargs)
 
     def static_settings(self):
+        SELECT2_USE_BUNDLED_SELECT2 = getattr(
+                settings, 'SELECT2_USE_BUNDLED_SELECT2', True)
+        if SELECT2_USE_BUNDLED_SELECT2:
+            SELECT2_VERSION = '4.0.13'
+            DEFAULT_SELECT2_CSS = 'easy_select2/vendor/select2-{}/css/select2.min.css'.format(SELECT2_VERSION)
+            DEFAULT_SELECT2_JS = 'easy_select2/vendor/select2-{}/js/select2.min.js'.format(SELECT2_VERSION)
+        else:  # use Django admin's copy
+            DEFAULT_SELECT2_CSS = 'admin/css/vendor/select2/select2.min.css'
+            DEFAULT_SELECT2_JS = 'admin/js/vendor/select2/select2.full.min.js'
+
         SELECT2_JS = getattr(
                 settings,
                 'SELECT2_JS',
-                'easy_select2/vendor/select2/js/select2.min.js',
+                DEFAULT_SELECT2_JS,
         )
         SELECT2_CSS = getattr(
                 settings,
                 'SELECT2_CSS',
-                'easy_select2/vendor/select2/css/select2.min.css',
+                DEFAULT_SELECT2_CSS,
         )
         SELECT2_USE_BUNDLED_JQUERY = getattr(
                 settings, 'SELECT2_USE_BUNDLED_JQUERY', True)
@@ -59,7 +68,7 @@ class Select2Mixin(object):
         ]
 
         if SELECT2_USE_BUNDLED_JQUERY:
-            jquery_min_file = 'easy_select2/vendor/jquery/jquery.min.js'
+            jquery_min_file = 'easy_select2/vendor/jquery/jquery-3.5.1.min.js'
             self.SELECT2_WIDGET_JS.insert(0, jquery_min_file)
         else:
             self.SELECT2_WIDGET_JS.insert(0, 'admin/js/jquery.init.js')
